@@ -1,19 +1,12 @@
 package Net::Identica;
-use Moose;
+use Net::Twitter;
 
 # use *all* digits for fBSD ports
-our $VERSION = '3.18000_00';
-$VERSION     = eval $VERSION; # numify for warning-free dev releases
+our $VERSION = '3.00002';
 
-extends 'Net::Twitter::Core';
-with map "Net::Twitter::Role::$_", qw/Legacy/;
+$VERSION = eval $VERSION; # numify for warning-free dev releases
 
-has '+apiurl'    => ( default => 'http://identi.ca/api' );
-has '+apirealm'  => ( default => 'Laconica API'         );
-
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
+sub new { shift; Net::Twitter->new(identica => 1, @_) }
 
 1;
 
@@ -31,33 +24,6 @@ Net::Identica - A perl interface to the Identi.ca Twitter Compatible API
 
   $nt->update('Hello, Identica friends!');
 
-=head1 DEPRECATED
-
-This module is a backwards compatibility wrapper for applications that used
-L<Net::Identica> packaged with C<Net::Twitter> versions 2.12 and earlier.
-Instead, use L<Net::Twitter> with the C<identica> option to gain all of the new
-features and functionality (OAuth, Search, exceptions on error, etc.).
-
-  use Net::Twitter;
-
-  # A simple, backwards compatible replacement for Net::Identica
-  my $identica = Net::Twitter->new(
-      legacy   => 1,
-      identica => 1,
-      username => $username,
-      password => $password,
-  );
-
-  # A more complex object with OAuth and some optional traits
-  my $identica = Net::Twitter->new(
-      traits => [qw/API::REST API::Search OAuth InflateObjects/],
-      identica            => 1,
-      consumer_key        => $consumer_key,
-      consumer_secret     => $consumer_secret,
-      access_token        => $token,
-      access_token_secret => $token_secret,
-  );
-
 =head1 DESCRIPTION
 
 The micro-blogging service L<http://identi.ca> provides a Twitter compatible API.
