@@ -1,16 +1,12 @@
 package Net::Twitter::OAuth;
-use Moose;
+use Net::Twitter;
 
 # use *all* digits for fBSD ports
-our $VERSION = '3.18000_00';
+our $VERSION = '3.00002';
+
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 
-extends  'Net::Twitter::Core';
-with map "Net::Twitter::Role::$_", qw/Legacy OAuth/;
-
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
+sub new { shift; Net::Twitter->new(traits => [qw/Legacy OAuth/], @_) }
 
 1;
 
