@@ -1,16 +1,12 @@
 package Net::Twitter::Search;
-use Moose;
+use Net::Twitter;
 
 # use *all* digits for fBSD ports
-our $VERSION = '3.18000_00';
+our $VERSION = '3.00002';
+
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 
-extends 'Net::Twitter::Core';
-with    "Net::Twitter::Role::Legacy";
-
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
+sub new { shift; Net::Twitter->new(traits => [qw/Legacy/], @_) }
 
 1;
 
@@ -26,13 +22,12 @@ Net::Twitter::Search - A perl interface to the Twitter Search API
 
   $nt = Net::Twitter::Search->new;
 
-  $tweets = $nt->search('perl_api');
+  $tweets = $nt->search('net_twitter');
 
 =head1 DESCRIPTION
 
-This module simply creates an instance of C<Net::Twitter> with the C<Legacy>
-trait for backwards compatibility with prior versions.  Consider
-L<Net::Twitter::Lite> if you need a lighter, non-Moose alternative.
+This module simply creates an instance of C<Net::Twitter> with the C<Legacy> trait
+set.
 
 See L<Net::Twitter> for full documentation.
 
